.. scipydirect documentation master file, created by
   sphinx-quickstart on Wed May 30 10:39:22 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. automodule:: scipydirect.__init__

Further reading
---------------

.. toctree::
   :maxdepth: 2

   install
   tutorial
   reference
   changelog
